==> humhub-1.3.18.tar.gz: humhub-1.3.18/protected/humhub/modules/ldap/messages/nl/base.php <==
<?php
return array (
  'A TLS/SSL is strongly favored in production environments to prevent passwords from be transmitted in clear text.' => 'Gebruik een TLS 1.2 of 1.3 verbinding om te voorkomen dat wachtwoorden als leesbare tekst worden verzonden.',
  'Base DN' => 'Base DN',
  'Defines the filter to apply, when login is attempted. %s replaces the username in the login action. Example: &quot;(sAMAccountName=%s)&quot; or &quot;(uid=%s)&quot;' => 'Definieert het filter dat moet worden toegepast, wanneer wordt geprobeerd aan te melden. %s vervangt de gebruikersnaam in de inlogactie. Voorbeeld: "(sAMAccountName=%s)" or "(uid=%s)"',
  'E-Mail Address Attribute' => 'E-mail adres Attribute',
  'Enable LDAP Support' => 'LDAP-ondersteuning inschakelen',
  'Encryption' => 'Encryptie',
  'Fetch/Update Users Automatically' => 'Automatisch gebruikers ophalen/bijwerken',
  'Hostname' => 'Hostname (computernaam)',
  'ID Attribute' => 'ID Attribute',
  'LDAP' => 'LDAP',
  'LDAP Attribute for E-Mail Address. Default: &quotmail&quot;' => 'LDAP-attribuut voor e-mailadres. Standaard: &amp;quotmail"',
  'LDAP Attribute for Username. Example: &quotuid&quot; or &quot;sAMAccountName&quot;' => 'LDAP-attribuut voor gebruikersnaam. Voorbeeld: &amp;quotuid" or "sAMAccountName"',
  'Limit access to users meeting this criteria. Example: &quot(objectClass=posixAccount)&quot; or &quot;(&(objectClass=person)(memberOf=CN=Workers,CN=Users,DC=myDomain,DC=com))&quot;' => 'Beperk de toegang tot gebruikers die aan dit criterium voldoen. Bijvoorbeeld: &amp;quot(objectClass=posixAccount)" or "(&amp;(objectClass=person)(memberOf=CN=Workers,CN=Users,DC=myDomain,DC=com))"',
  'Login Filter' => 'Aanmeldfilter',
  'Not changeable LDAP attribute to unambiguously identify the user in the directory. If empty the user will be determined automatically by e-mail address or username. Examples: objectguid (ActiveDirectory) or uidNumber (OpenLDAP)' => 'Niet-veranderbaar LDAP-attribuut om de gebruiker ondubbelzinnig in de directory te identificeren. Indien leeg, wordt de gebruiker automatisch bepaald op basis van het e-mailadres of de gebruikersnaam. Voorbeelden: objectguid (ActiveDirectory) or uidNumber (OpenLDAP)',
  'Password' => 'Wachtwoord',
  'Port' => 'Poort',
  'Specify your LDAP-backend used to fetch user accounts.' => 'Geef uw LDAP-backend op die wordt gebruikt om gebruikersaccounts op te halen.',
  'Status: Error! (Message: {message})' => 'Status: Fout! (Bericht: {message})',
  'Status: OK! ({userCount} Users)' => 'Status: OK! ({userCount} Users)',
  'Status: Warning! (No users found using the ldap user filter!)' => 'Status: Waarschuwing! (Geen gebruikers gevonden met het ldap gebruikersfilter!)',
  'The default base DN used for searching for accounts.' => 'De standaardbasis-DN die wordt gebruikt voor het zoeken naar accounts.',
  'The default credentials password (used only with username above).' => 'Het standaard wachtwoord voor inloggegevens (alleen gebruikt met gebruikersnaam hierboven).',
  'The default credentials username. Some servers require that this be in DN form. This must be given in DN form if the LDAP server requires a DN to bind and binding should be possible with simple usernames.' => 'De standaard gebruikersnaam voor inloggegevens. Sommige servers vereisen dat dit in DN-vorm is. Dit moet in DN-vorm worden gegeven als de LDAP-server een DN vereist om te binden en binding mogelijk zou moeten zijn met eenvoudige gebruikersnamen.',
  'User Filer' => 'Gebruikersfiler',
  'Username' => 'Gebruikersnaam',
  'Username Attribute' => 'Gebruikersnaam Attribute',
);

==> humhub-1.5.2.tar.gz: humhub-1.5.2/protected/humhub/modules/ldap/messages/nl/base.php <==
<?php
return array (
  'A TLS/SSL is strongly favored in production environments to prevent passwords from be transmitted in clear text.' => 'Gebruik een TLS 1.2 of 1.3 verbinding om te voorkomen dat wachtwoorden als leesbare tekst worden verzonden.',
  'Base DN' => 'Base DN',
  'Defines the filter to apply, when login is attempted. %s replaces the username in the login action. Example: &quot;(sAMAccountName=%s)&quot; or &quot;(uid=%s)&quot;' => 'Definieert het filter dat moet worden toegepast, wanneer wordt geprobeerd aan te melden. %s vervangt de gebruikersnaam in de inlogactie. Voorbeeld: "(sAMAccountName=%s)" or "(uid=%s)"',
  'E-Mail Address Attribute' => 'E-mail adres Attribute',
  'Enable LDAP Support' => 'LDAP-ondersteuning inschakelen',
  'Encryption' => 'Encryptie',
  'Fetch/Update Users Automatically' => 'Automatisch gebruikers ophalen/bijwerken',
  'Hostname' => 'Hostname (computernaam)',
  'ID Attribute' => 'ID Attribute',
  'LDAP' => 'LDAP',
  'LDAP Attribute for E-Mail Address. Default: &quot;mail&quot;' => 'LDAP-kenmerk voor e-mailadres. Standaard: "mail"',
  'LDAP Attribute for Username. Example: &quot;uid&quot; or &quot;sAMAccountName&quot;' => 'LDAP-kenmerk voor gebruikersnaam. Voorbeeld: "uid" of " sAMAccountName"',
  'Limit access to users meeting this criteria. Example: &quot;(objectClass=posixAccount)&quot; or &quot;(&(objectClass=person)(memberOf=CN=Workers,CN=Users,DC=myDomain,DC=com))&quot;' => 'Beperk de toegang tot gebruikers die aan deze criteria voldoen. Voorbeeld: "(objectClass = posixAccount)" of "(&amp; (objectClass = person) (memberOf = CN = Workers, CN = Users, DC = myDomain, DC = com))"',
  'Login Filter' => 'Aanmeldfilter',
  'Not changeable LDAP attribute to unambiguously identify the user in the directory. If empty the user will be determined automatically by e-mail address or username. Examples: objectguid (ActiveDirectory) or uidNumber (OpenLDAP)' => 'Niet-veranderbaar LDAP-attribuut om de gebruiker ondubbelzinnig in de directory te identificeren. Indien leeg, wordt de gebruiker automatisch bepaald op basis van het e-mailadres of de gebruikersnaam. Voorbeelden: objectguid (ActiveDirectory) or uidNumber (OpenLDAP)',
  'Password' => 'Wachtwoord',
  'Port' => 'Poort',
  'Specify your LDAP-backend used to fetch user accounts.' => 'Geef uw LDAP-backend op die wordt gebruikt om gebruikersaccounts op te halen.',
  'Status: Error! (Message: {message})' => 'Status: Fout! (Bericht: {message})',
  'Status: OK! ({userCount} Users)' => 'Status: OK! ({userCount} Users)',
  'Status: Warning! (No users found using the ldap user filter!)' => 'Status: Waarschuwing! (Geen gebruikers gevonden met het ldap gebruikersfilter!)',
  'The default base DN used for searching for accounts.' => 'De standaardbasis-DN die wordt gebruikt voor het zoeken naar accounts.',
  'The default credentials password (used only with username above).' => 'Het standaard wachtwoord voor inloggegevens (alleen gebruikt met gebruikersnaam hierboven).',
  'The default credentials username. Some servers require that this be in DN form. This must be given in DN form if the LDAP server requires a DN to bind and binding should be possible with simple usernames.' => 'De standaard gebruikersnaam voor inloggegevens. Sommige servers vereisen dat dit in DN-vorm is. Dit moet in DN-vorm worden gegeven als de LDAP-server een DN vereist om te binden en binding mogelijk zou moeten zijn met eenvoudige gebruikersnamen.',
  'User Filer' => 'Gebruikersfiler',
  'Username' => 'Gebruikersnaam',
  'Username Attribute' => 'Gebruikersnaam Attribute',
);
